@@ -1,20 +1,24 @@
 from __future__ import absolute_import, unicode_literals
 
 import os
+import re
 import sys
+import sysconfig
 from abc import ABCMeta, abstractmethod
 
-import six
+from six import add_metaclass
+
+from virtualenv.util.six import ensure_text
 
 from .activator import Activator
 
 if sys.version_info >= (3, 7):
-    from importlib.resources import read_text
+    from importlib.resources import read_binary
 else:
-    from importlib_resources import read_text
+    from importlib_resources import read_binary
 
 
-@six.add_metaclass(ABCMeta)
+@add_metaclass(ABCMeta)
 class ViaTemplateActivator(Activator):
     @abstractmethod
     def templates(self):
@@ -23,31 +27,45 @@ class ViaTemplateActivator(Activator):
     def generate(self, creator):
         dest_folder = creator.bin_dir
         replacements = self.replacements(creator, dest_folder)
-        self._generate(replacements, self.templates(), dest_folder, creator)
+        generated = self._generate(replacements, self.templates(), dest_folder, creator)
         if self.flag_prompt is not None:
             creator.pyenv_cfg["prompt"] = self.flag_prompt
+        return generated
 
     def replacements(self, creator, dest_folder):
+        current_platform = sysconfig.get_platform()
+        platforms = ["mingw", "cygwin", "msys"]
+        if any(platform in current_platform for platform in platforms):
+            pattern = re.compile("^([A-Za-z]):(.*)")
+            match = pattern.match(str(creator.dest))
+            virtual_env = "/" + match.group(1).lower() + match.group(2)
+        else:
+            virtual_env = str(creator.dest)
         return {
             "__VIRTUAL_PROMPT__": "" if self.flag_prompt is None else self.flag_prompt,
-            "__VIRTUAL_ENV__": six.ensure_text(str(creator.dest)),
+            "__VIRTUAL_ENV__": ensure_text(virtual_env),
             "__VIRTUAL_NAME__": creator.env_name,
-            "__BIN_NAME__": six.ensure_text(str(creator.bin_dir.relative_to(creator.dest))),
-            "__PATH_SEP__": six.ensure_text(os.pathsep),
+            "__BIN_NAME__": ensure_text(str(creator.bin_dir.relative_to(creator.dest))),
+            "__PATH_SEP__": ensure_text(os.pathsep),
         }
 
     def _generate(self, replacements, templates, to_folder, creator):
+        generated = []
         for template in templates:
             text = self.instantiate_template(replacements, template, creator)
             dest = to_folder / self.as_name(template)
-            dest.write_text(text, encoding="utf-8")
+            # use write_bytes to avoid platform specific line normalization (\n -> \r\n)
+            dest.write_bytes(text.encode("utf-8"))
+            generated.append(dest)
+        return generated
 
     def as_name(self, template):
         return template.name
 
     def instantiate_template(self, replacements, template, creator):
-        # read text and do replacements
-        text = read_text(self.__module__, str(template), encoding="utf-8", errors="strict")
+        # read content as binary to avoid platform specific line normalization (\n -> \r\n)
+        binary = read_binary(self.__module__, str(template))
+        text = binary.decode("utf-8", errors="strict")
         for key, value in replacements.items():
             value = self._repr_unicode(creator, value)
             text = text.replace(key, value)
