@@ -29,7 +29,7 @@ from virtualenv.seed.wheels.periodic_update import (
     trigger_update,
 )
 from virtualenv.util.path import Path
-from virtualenv.util.subprocess import DETACHED_PROCESS
+from virtualenv.util.subprocess import CREATE_NO_WINDOW
 
 
 @pytest.fixture(autouse=True)
@@ -132,13 +132,22 @@ _UP_NOW = datetime.now()
 _UPDATE_SKIP = {
     "started_just_now_no_complete": UpdateLog(started=_UP_NOW, completed=None, versions=[], periodic=True),
     "started_1_hour_no_complete": UpdateLog(
-        started=_UP_NOW - timedelta(hours=1), completed=None, versions=[], periodic=True,
+        started=_UP_NOW - timedelta(hours=1),
+        completed=None,
+        versions=[],
+        periodic=True,
     ),
     "completed_under_two_weeks": UpdateLog(
-        started=None, completed=_UP_NOW - timedelta(days=14), versions=[], periodic=True,
+        started=None,
+        completed=_UP_NOW - timedelta(days=14),
+        versions=[],
+        periodic=True,
     ),
     "started_just_now_completed_two_weeks": UpdateLog(
-        started=_UP_NOW, completed=_UP_NOW - timedelta(days=14, seconds=1), versions=[], periodic=True,
+        started=_UP_NOW,
+        completed=_UP_NOW - timedelta(days=14, seconds=1),
+        versions=[],
+        periodic=True,
     ),
     "started_1_hour_completed_two_weeks": UpdateLog(
         started=_UP_NOW - timedelta(hours=1),
@@ -162,7 +171,10 @@ def test_periodic_update_skip(u_log, mocker, for_py_version, session_app_data, f
 _UPDATE_YES = {
     "never_started": UpdateLog(started=None, completed=None, versions=[], periodic=False),
     "started_1_hour": UpdateLog(
-        started=_UP_NOW - timedelta(hours=1, microseconds=1), completed=None, versions=[], periodic=False,
+        started=_UP_NOW - timedelta(hours=1, microseconds=1),
+        completed=None,
+        versions=[],
+        periodic=False,
     ),
     "completed_two_week": UpdateLog(
         started=_UP_NOW - timedelta(days=14, microseconds=2),
@@ -224,7 +236,7 @@ def test_trigger_update_no_debug(for_py_version, session_app_data, tmp_path, moc
     assert args == ([sys.executable, "-c", cmd],)
     expected = {"stdout": subprocess.PIPE, "stderr": subprocess.PIPE}
     if sys.platform == "win32":
-        expected["creationflags"] = DETACHED_PROCESS
+        expected["creationflags"] = CREATE_NO_WINDOW
     assert kwargs == expected
     assert process.communicate.call_count == 0
 
@@ -389,7 +401,9 @@ def test_new_version_eq():
 
 def test_new_version_ne():
     assert NewVersion("a", datetime.now(), datetime.now()) != NewVersion(
-        "a", datetime.now(), datetime.now() + timedelta(hours=1),
+        "a",
+        datetime.now(),
+        datetime.now() + timedelta(hours=1),
     )
 
 
